#!/tvbin/tivosh
# ************************************************************
# AltEPG Project Source Code Version Control
# $FileID: git::root/hack/bin/setUIText.tcl $
# $Revision: altepg1.0c-2011-10-16_1 root 2011-10-01 12:01:00 +0100 buglist update $
# Description: Make alterations to various UI texts in MFS DB
# ************************************************************

source $tcl_library/tv/log.tcl

# ------------------------------------------------------------------------------------------
# locate an object in the database and return a reference to it

proc OpenObject {db objspec} {
  if {[string range $objspec 0 0] == "/"} {
    set obj [db $db open $objspec]
  } elseif { [regexp {([0-9]*)/(.*)} $objspec junk fsid subobjid] } {
    set obj [db $db openidconstruction $fsid $subobjid]
  } else {
    set obj [db $db openid $objspec]
  }
  return $obj
}

# ------------------------------------------------------------------------------------------
# set the UI text for a particular resource/element

proc setUIText { resource element old new } {
  global db
  global mode
  global fsidGeneral
  global fsidGuidedSetup
  global fsidServiceSetup
  global fsidPickProgrammes
  global fsidCallProgress
  global fsidRecordingOptions
  global fsidSatelliteSetup
  global errorCount
  global successCount
  
  switch -exact -- $resource {
    General           {set resourceid $fsidGeneral}
    GuidedSetup       {set resourceid $fsidGuidedSetup}
    ServiceSetup      {set resourceid $fsidServiceSetup}
    PickProgrammes    {set resourceid $fsidPickProgrammes}
    CallProgress      {set resourceid $fsidCallProgress}
    RecordingOptions  {set resourceid $fsidRecordingOptions}
    SatelliteSetup    {set resourceid $fsidSatelliteSetup}
    default           {putlog "Error - unrecognised resource $resource"}
  }
  set objid "$resourceid/$element"
  RetryTransaction {
    set obj [OpenObject $db $objid]
    set currval [dbobj $obj get String]
    
    # modes:
    #  normal        - set the element to $new, but only if its current value = $old
    #  reverse       - set the element to $old, but only if its current value = $new
    #  normal-force  - set the element to $new, regardless of current value
    #  reverse-force - set the element to $old, regardless of current value
    #  normal-test   - as normal but just report what would be done
    #  reverse-test  - as reverse but just report what would be done
    
    if { [regexp {(normal|reverse)(\-force|\-test)?} $mode junk direction qualifier] } {
      if { $direction == "normal" } {
	set fromval $old
	set toval $new
      } else {
	set fromval $new
	set toval $old
      }
      if { $currval == "\{$toval\}" || $currval == $toval } {
	putlog "INFO: Not setting $resource/$element : already has correct value"
	putlog "Existing: $currval"
        set successCount [expr $successCount + 1]
      } elseif { $currval == "\{$fromval\}" || $currval == $fromval || $qualifier == "-force"} {
	if { $qualifier != "-test" } {
	  putlog "Setting $resource/$element"
	  putlog "Existing: $currval"
	  putlog "Setting : $toval"
          dbobj $obj set String $toval
          set newval [dbobj $obj get String]
	  putlog "Now set : $newval"
	} else {
	  putlog "Would set $resource/$element"
	  putlog "Existing: $currval"
	  putlog "Setting : $toval"
	}
        set successCount [expr $successCount + 1]
      } else {
	putlog "ERROR: Not setting $resource/$element : existing value doesn't match"
	putlog "Existing: $currval"
	putlog "Expected: $fromval"
        set errorCount [expr $errorCount + 1]
      }
    } else {
      putlog "ERROR: Invalid mode $mode - not doing anything"
      set errorCount [expr $errorCount + 1]
    }
  }
}

# ------------------------------------------------------------------------------------------
# given a database path, this returns the fsid of the referenced object

proc getidfrompath { path } {
  global db
  RetryTransaction {
    set dbobj [OpenObject $db $path]
    set fsid [dbobj $dbobj fsid]
  }
#  putlog "Path $path; fsid $fsid"
  return $fsid
}

# ------------------------------------------------------------------------------------------
# Start of ***MAIN***

# open the database and determine the fsids for each resource group

set db [dbopen]
set fsidGeneral          [getidfrompath "/Server/468091"]
set fsidGuidedSetup      [getidfrompath "/Server/468105"]
set fsidPickProgrammes   [getidfrompath "/Server/468106"]
set fsidServiceSetup     [getidfrompath "/Server/468115"]
set fsidCallProgress     [getidfrompath "/Server/468122"]
set fsidRecordingOptions [getidfrompath "/Server/468123"]
set fsidSatelliteSetup   [getidfrompath "/Server/468124"]

# check we have found the right groups

set errorCount 0
set successCount 0

putlog "Starting setUIText."
putlog "Testing current configuration."
set mode normal-test
setUIText General          12 "No information available." ""
setUIText GuidedSetup      12 "Customise Channels" ""
setUIText ServiceSetup     22 "Error Detected (#51)" ""
setUIText CallProgress     13 "Succeeded" ""
setUIText PickProgrammes   12 "Record this programme" ""
setUIText RecordingOptions 12 "Record %s with these options" ""
setUIText SatelliteSetup   12 "Satellite Dish Setup" ""

if { $errorCount > 0 } {
  putlog "ERROR: current text strings not as expected - terminating"
  exit 2
}

# get mode from command line - default is 'normal'

set mode [lindex $argv 0]
if { $mode == "" } {
  set mode "normal-force" 
}

set errorCount 0
set successCount 0

# Fire off each of the commands (comments from MrTickle)

# Rename wording on the delete screen

setUIText General 107 "Have you finished with this programme?  If you delete it now it will make space for more programmes to be recorded." "Have you watched all of this programme? If you delete it now, it'll make space for more recordings."
setUIText General 108 "Delete this recording now" "Delete this programme now"
setUIText General 109 "Don't delete" "Save it for later"

# Fix the USA English "one time" that should be "once" in Manual Record:

setUIText General 124 "One Time" "Once"

# Make the "Manual:" tag shorter to show more of the title on Now Playing. NB this could be anything. Or nothing!

setUIText General 134 "Manual: %s" "M: %s"

# Change the "Now Playing" page heading & menu entry:
#	USA TiVos at one time had "Now Playing on TiVo", later "Now Playing List" - change to suit

setUIText General 17 "Now Playing" "Now Playing on TiVo"

# optional self-indulgence: - change to suit 

setUIText General 18 "AltEPG TiVo Central" "AltEPG - TiVo Main Menu"
setUIText General 18 "TiVo Central" "AltEPG - TiVo Main Menu"

# Channel Highlights are called Showcases in the USA, I like that title and it's helpful to clarify they are the same:

setUIText General 21 "Channel Highlights" "Channel Highlights (Showcases)"

# I noticed that screenshots of later USA software had nicer descriptions, so copied them:

setUIText General 22 "Pick Programmes to Record" "Find Programmes to Record"
setUIText General 33 "Search Using WishLists" "WishList Search (Actor, Category or Keyword)"
setUIText General 42 "TiVo's Suggestions" "TiVo Suggestions"
setUIText GuidedSetup 424 "TiVo's Suggestions" "TiVo Suggestions"
setUIText General 19 "TiVo's Suggestions" "TiVo Suggestions"

# Fix stray colon in "no upcoming episodes:":

setUIText General 437 "%s has no upcoming episodes:" "%s has no upcoming episodes."

# ===================================================================================================================================================
# BM

setUIText GuidedSetup 48 "TiVo Service Terms" "AltEPG TiVo Service Terms"
setUIText GuidedSetup 47 {Welcome to the TiVo Service! TiVo's Service Agreement
can be found in the material supplied with your Digital
 Video Recorder and also on www.tivo.co.uk.
By completing Guided Setup and using the TiVo Service
(even during the grace period), you are agreeing to
the terms in the TiVo Service Agreement.  We
encourage you to read through it.  If you agree to the
terms in the TiVo Service Agreement, press SELECT to
continue.} {Welcome to the AltEPG TiVo Service! 
The words below relate to the official TiVo service, which
is no longer available in the UK. You may however still
be bound by them. TiVo's Service Agreement can be found in 
the material supplied with your Digital Video Recorder
and also on www.tivo.co.uk. By completing Guided Setup
and using the TiVo Service (even during the grace period),
you are agreeing to the terms in the TiVo Service
Agreement.  We encourage you to read through it.
If you agree to the terms in the TiVo Service Agreement, 
press SELECT to continue.}

setUIText General 285 {The Recorder cannot display Live TV. Try these tips, one at a time:

1. Change channels several times.
2. Verify cable/satellite box is on.
3. Check cable connections.
4. Verify video source; try connecting
				it directly to your TV.
5. From TiVo Central, choose "Messages &
				Setup," then "System Reset," and select
				"Restart the Recorder."} {The Recorder cannot display Live TV. Try these tips, one at a time:

1. Change channels several times.
2. Verify cable/satellite box is on.
3. Check cable connections.
4. Verify video source; try connecting
				it directly to your TV.
5. From Main Menu, choose "Messages &
				Setup," then "System Reset," and select
				"Restart the Recorder."}

setUIText General 615 "The Recorder is currently receiving data to keep your TiVo Service up to date.  To watch a program from Now Playing, without interrupting the delivery, press the TiVo button.  To watch a program on Live TV, enter a channel number, press CHAN UP/DOWN, or select a program from the Guide. The Recorder will try to reacquire the data at a later time." "The Recorder is currently receiving data to keep your TiVo Service up to date.  To watch a programme from Now Playing, without interrupting the delivery, press the TiVo button.  To watch a programme on Live TV, enter a channel number, press CHAN UP/DOWN, or select a programme from the Guide. The Recorder will try to reacquire the data at a later time."
setUIText GuidedSetup 45 "You have completed Guided Setup.  Please contact TiVo to activate your service account:  On the Web at www.tivo.com -OR- by calling .\n\nPress the TiVo button to continue.  This button will always take you to the TiVo Central screen.\n\nIf you would like to set up your Favourite Channels or program your Remote to control your TV, go to Setup from TiVo Central." "You have completed AltEPG Guided Setup.  Please contact AltEPG at www.altepg.com to activate your service account.\n\nPress the TiVo button to continue.  This button will always take you to the TiVo Menu.\n\nIf you would like to set up your Favourite Channels or program your Remote to control your TV, go to Setup from TiVo Menu."
setUIText GuidedSetup 46 "You have completed Guided Setup.  Your TiVo Service has already been activated.\n\nPress the TiVo button to continue.  This button will always take you to the TiVo Central screen.\n\nIf you would like to set up your Favourite Channels or program your Remote to control your TV, go to Setup from TiVo Central." "You have completed AltEPG Guided Setup.  Your AltEPG TiVo Service has already been activated.\n\nPress the TiVo button to continue.  This button will always take you to the TiVo Menu.\n\nIf you would like to set up your Favourite Channels or program your Remote to control your TV, go to Setup from the TiVo Menu."
setUIText General 602 {You must make a daily call to get more Programme Guide data. Go to Messages and Setup, Recorder & Phone Setup, Phone Connection and choose "Make Daily Call Now."} {You must make a daily call to get more Programme Guide data. Go to Messages and Setup, Recorder & Call Setup, Phone/Network Connection and choose "Make Daily Call Now."}

setUIText GuidedSetup 38 {The Recorder is now going to use your phone to call the TiVo Service (toll-free) to get your service information.  This call will take about 1-3 minutes.

After this phone call, the Recorder will process the data for about 5-15 minutes} {The Recorder is now going to use your phone or network to call the AltEPG TiVo Service to get your service information.  This call will take about 1-3 minutes.

After this call, the Recorder will process the data for about 5-15 minutes}

setUIText GuidedSetup 266 "Phone Connection" "Phone/Network Connection"
setUIText GuidedSetup 269 "Change Dialling Options" "Change Phone/Network Options"
setUIText GuidedSetup 281 "Phone Call:" "Phone/Network Call:"
# ===================================================================================================================================================
setUIText GuidedSetup 39 {The Recorder is now going to use your phone to call the TiVo Service to get your Programme Guide data.  This call will take about 20-30 minutes.

After Guided Setup, the Recorder will take 4-8 hours to organise the Programme Guide data. During this time, some TiVo Service functions will not be available.} {The Recorder is now going to use your phone/network to call the AltEPG TiVo Service to get your Programme Guide data.  This call will take about 20-30 minutes by phone or 1 minute if connecting via network.

After Guided Setup, the Recorder will take 4-8 hours to organise the Programme Guide data. During this time, some TiVo Service functions will not be available.}

# ===================================================================================================================================================
setUIText GuidedSetup 77 {Guided Setup will take about 35 minutes of your time.

Be sure your phone cable is connected to the Recorder.  The Recorder will make two phone calls during Guided Setup.  After the second call has hung up, you can use your phone while Guided Setup continues.} {Guided Setup will take about 35 minutes of your time.

Be sure your phone/network cable is connected to the Recorder.  The Recorder will make two phone/network calls during Guided Setup.  After the second call has hung up, you can use your phone while Guided Setup continues.}
# ===================================================================================================================================================
setUIText GuidedSetup 204 {Phone Dialling Options} {Phone/Network Options}
# ===================================================================================================================================================
setUIText ServiceSetup 57 {You must have a valid TiVo Service account to use TiVo functionality. Please call Customer Service at .

If you have already activated, thank you.  Your TiVo Service account status will be updated within a few days.  Or, you can make a daily call now to check your account status. 

To make a daily call now:
- Check that the phone line is connected
- Then, from TiVo Central choose "Messages and Setup"
- Choose "Recorder & Phone Setup"
- Choose "Phone Connection"
- Choose "Make Daily Call Now"
If the call doesn't succeed, check the Phone Troubleshooting tips in "Messages and Setup."

If the Recorder is still unable to successfully call the TiVo Service after following the Phone Troubleshooting tips, please call Customer Service at .} {You must register your TiVo to use AltEPG TiVo functionality. Visit www.altepg.com to register.

If you have already registered, thank you.  Your AltEPG registration status should now be up to date.  You can make a daily call now to check your registration status.

To make a daily call now:
- Check that the phone line or network is connected
- Then, from the TiVo Menu choose "Messages and Setup"
- Choose "Recorder & Call Setup"
- Choose "Phone/Network Connection"
- Choose "Make Daily Call Now"
If the call doesn't succeed, check the Phone Troubleshooting tips in "Messages and Setup."

If the Recorder is still unable to successfully call the AltEPG TiVo Service after following the Call Troubleshooting tips, please call visit www.altepg.com}

# ===================================================================================================================================================
setUIText ServiceSetup 65 {You must have a valid TiVo Service account to use TiVo functionality. To re-activate your account, you must call Customer Service at .

If you have already activated, thank you.  Your TiVo Service account status will be updated within a few days.  Or, you can make a daily call now to check your account status. (If you have just re-activated, please wait several hours for processing to complete before making a daily call.) 

To make a daily call now:
- Check that the phone line is connected
- Then, from TiVo Central choose "Messages and Setup"
- Choose "Recorder & Phone Setup"
- Choose "Phone Connection"
- Choose "Make Daily Call Now"
If the call doesn't succeed, check the Phone Troubleshooting tips in "Messages and Setup."

If the Recorder is still unable to successfully call the TiVo Service after following the Phone Troubleshooting tips, please call Customer Service at . } {You must register your TiVo to use AltEPG TiVo functionality. Visit www.altepg.com to register.

If you have already registered, thank you.  Your AltEPG registration status should now be up to date.  You can make a daily call now to check your registration status.

To make a daily call now:
- Check that the phone line or network is connected
- Then, from the TiVo Menu choose "Messages and Setup"
- Choose "Recorder & Call Setup"
- Choose "Phone/Network Connection"
- Choose "Make Daily Call Now"
If the call doesn't succeed, check the Phone Troubleshooting tips in "Messages and Setup."

If the Recorder is still unable to successfully call the AltEPG TiVo Service after following the Call Troubleshooting tips, please call visit www.altepg.com}

# ===================================================================================================================================================
setUIText ServiceSetup 73 {The Recorder has only %d day%s of Programme Guide data left. After that, no Season Passes or programmes will be recorded.  Channel Highlights, Inside TiVo, and Software Updates will not be available. To get more Programme Guide data, the Recorder must make a successful daily call. 

To make a daily call now:
- Check that the phone line is connected
- Then, from TiVo Central choose "Messages and Setup"
- Choose "Recorder & Phone Setup"
- Choose "Phone Connection"
- Choose "Make Daily Call Now"
If the call doesn't succeed, check the Phone Troubleshooting tips in "Messages and Setup."

If the Recorder is still unable to successfully call the TiVo Service after following the Phone Troubleshooting tips, please call Customer Service at .} {The Recorder has only %d day%s of Programme Guide data left. After that, no Season Passes or programmes will be recorded.  Channel Highlights, Inside TiVo, and Software Updates will not be available. To get more Programme Guide data, the Recorder must make a successful daily call. 

To make a daily call now:
- Check that the phone line is connected
- Then, from the TiVo Menu choose "Messages and Setup"
- Choose "Recorder & Call Setup"
- Choose "Phone/Network Connection"
- Choose "Make Daily Call Now"
If the call doesn't succeed, check the Phone Troubleshooting tips in "Messages and Setup."

If the Recorder is still unable to successfully call the TiVo Service after following the Phone Troubleshooting tips, please visit www.altepg.com}

# ===================================================================================================================================================
setUIText ServiceSetup 81 {The Recorder has only %d day%s of Programme Guide data left. After that, no Season Passes or programmes will be recorded.  Channel Highlights, Inside TiVo, and Software Updates will not be available. To get more Programme Guide data, the Recorder must make a successful daily call. 

To make a daily call now:
- Check that the phone line is connected
- Then, from TiVo Central choose "Messages and Setup"
- Choose "Recorder & Phone Setup"
- Choose "Phone Connection"
- Choose "Make Daily Call Now"
If the call doesn't succeed, check the Phone Troubleshooting tips in "Messages and Setup."

If the Recorder is still unable to successfully call the TiVo Service after following the Phone Troubleshooting tips, please call Customer Service at .} {The Recorder has only %d day%s of Programme Guide data left. After that, no Season Passes or programmes will be recorded.  Channel Highlights, Inside TiVo, and Software Updates will not be available. To get more Programme Guide data, the Recorder must make a successful daily call. 

To make a daily call now:
- Check that the phone line is connected
- Then, from the TiVo Menu choose "Messages and Setup"
- Choose "Recorder & Call Setup"
- Choose "Phone/Network Connection"
- Choose "Make Daily Call Now"
If the call doesn't succeed, check the Phone Troubleshooting tips in "Messages and Setup."

If the Recorder is still unable to successfully call the TiVo Service after following the Phone Troubleshooting tips, please visit www.altepg.com}

# ===================================================================================================================================================
setUIText ServiceSetup 89 {The Recorder has no more Programme Guide data. The Recorder must make a successful daily call to resume recording Season Passes and programmes, to update Channel Highlights and Inside TiVo, and to receive Software Updates. 

To make a daily call now:
- Check that the phone line is connected
- Then, from TiVo Central choose "Messages and Setup"
- Choose "Recorder & Phone Setup"
- Choose "Phone Connection"
- Choose "Make Daily Call Now"
If the call doesn't succeed, check the Phone Troubleshooting tips in "Messages and Setup."

If the Recorder is still unable to successfully call the TiVo Service after following the Phone Troubleshooting tips, please call Customer Service at .} {The Recorder has no more Programme Guide data. The Recorder must make a successful daily call to resume recording Season Passes and programmes, to update Channel Highlights and Inside TiVo, and to receive Software Updates. 

To make a daily call now:
- Check that the phone line is connected
- Then, from the TiVo Menu choose "Messages and Setup"
- Choose "Recorder & Call Setup"
- Choose "Phone/Network Connection"
- Choose "Make Daily Call Now"
If the call doesn't succeed, check the Phone Troubleshooting tips in "Messages and Setup."

If the Recorder is still unable to successfully call the TiVo Service after following the Phone Troubleshooting tips, please visit www.altepg.com}

# ===================================================================================================================================================
setUIText ServiceSetup 113 {The TiVo Recorder has not made a successful daily call for the past %d day%s. A daily call must succeed within %d day%s to avoid an interruption of the TiVo Service. After that, no Season Passes or programmes will be recorded. Channel Highlights, Inside TiVo, and Software Updates will not be available. 

To make a daily call now:
- Check that the phone line is connected
- Then, from TiVo Central choose "Messages and Setup"
- Choose "Recorder & Phone Setup"
- Choose "Phone Connection"
- Choose "Make Daily Call Now"
If the call doesn't succeed, check the Phone Troubleshooting tips in "Messages and Setup."

If the Recorder is still unable to successfully call the TiVo Service after following the Phone Troubleshooting tips, please call Customer Service at .} {The TiVo Recorder has not made a successful daily call for the past %d day%s. A daily call must succeed within %d day%s to avoid an interruption of the TiVo Service. After that, no Season Passes or programmes will be recorded. Channel Highlights, Inside TiVo, and Software Updates will not be available. 

To make a daily call now:
- Check that the phone line is connected
- Then, from the TiVo Menu choose "Messages and Setup"
- Choose "Recorder & Call Setup"
- Choose "Phone/Network Connection"
- Choose "Make Daily Call Now"
If the call doesn't succeed, check the Phone Troubleshooting tips in "Messages and Setup."

If the Recorder is still unable to successfully call the TiVo Service after following the Phone Troubleshooting tips, please visit www.altepg.com}

# ===================================================================================================================================================
setUIText ServiceSetup 121 {The TiVo Recorder has not made a successful daily call for the past %d day%s. A daily call must succeed within %d day%s to avoid an interruption of the TiVo Service. After that, no Season Passes or programmes will be recorded. Channel Highlights, Inside TiVo, and Software Updates will not be available. 

To make a daily call now:
- Check that the phone line is connected
- Then, from TiVo Central choose "Messages and Setup"
- Choose "Recorder & Phone Setup"
- Choose "Phone Connection"
- Choose "Make Daily Call Now"
If the call doesn't succeed, check the Phone Troubleshooting tips in "Messages and Setup."

If the Recorder is still unable to successfully call the TiVo Service after following the Phone Troubleshooting tips, please call Customer Service at .} {The TiVo Recorder has not made a successful daily call for the past %d day%s. A daily call must succeed within %d day%s to avoid an interruption of the TiVo Service. After that, no Season Passes or programmes will be recorded. Channel Highlights, Inside TiVo, and Software Updates will not be available. 

To make a daily call now:
- Check that the phone line is connected
- Then, from the TiVo Menu choose "Messages and Setup"
- Choose "Recorder & Call Setup"
- Choose "Phone/Network Connection"
- Choose "Make Daily Call Now"
If the call doesn't succeed, check the Phone Troubleshooting tips in "Messages and Setup."

If the Recorder is still unable to successfully call the TiVo Service after following the Phone Troubleshooting tips, please visit www.altepg.com}

# ===================================================================================================================================================
setUIText ServiceSetup 129 {The TiVo Recorder has not made a successful daily call for more than 30 days.  No TiVo Service functionality will be available until the Recorder makes a successful daily call. Until then, no Season Passes and programmes will be recorded. Channel Highlights, Inside TiVo, and Software Updates will not be available. 

To make a daily call now:
- Check that the phone line is connected
- Then, from TiVo Central choose "Messages and Setup"
- Choose "Recorder & Phone Setup"
- Choose "Phone Connection"
- Choose "Make Daily Call Now"
If the call doesn't succeed, check the Phone Troubleshooting tips in "Messages and Setup."

If the Recorder is still unable to successfully call the TiVo Service after following the Phone Troubleshooting tips, please call Customer Service at .} {The TiVo Recorder has not made a successful daily call for more than 30 days.  No TiVo Service functionality will be available until the Recorder makes a successful daily call. Until then, no Season Passes and programmes will be recorded. Channel Highlights, Inside TiVo, and Software Updates will not be available. 

To make a daily call now:
- Check that the phone line is connected
- Then, from the TiVo Menu choose "Messages and Setup"
- Choose "Recorder & Call Setup"
- Choose "Phone/Network Connection"
- Choose "Make Daily Call Now"
If the call doesn't succeed, check the Phone Troubleshooting tips in "Messages and Setup."

If the Recorder is still unable to successfully call the TiVo Service after following the Phone Troubleshooting tips, please visit www.altepg.com}

# ===================================================================================================================================================

setUIText SatelliteSetup 92 {You have completed Guided Setup.

If you have not yet activated your TiVo Service, you may do so by calling Customer Service at .

Press the TiVo button to continue.  This button will always take you to "TiVo Central".  You can find other setup options in "Messages and Setup".} {You have completed Guided Setup.

If you have not yet activated your AltEPG TiVo Service, you may do so by visiting www.altepg.com .

Press the TiVo button to continue.  This button will always take you to the "TiVo Menu".  You can find other setup options in "Messages and Setup".}

# ===================================================================================================================================================

# when the telephone number for Sky changed, I changed it here too. This could now be used to say "go to the AltEPG forum on the internet at www..."  etc instead of a number.
# @@ need to find out where this is used...

setUIText GuidedSetup 182 "    Call 08702 418486" "    visit www.altepg.com"
setUIText GuidedSetup 194 "    Call 08702 418486" "    visit www.altepg.com"

# Fix capitalisation of acronym "NICAM":

setUIText GuidedSetup 568 "Main Audio Programme (Nicam stereo)" "Main Audio Programme (NICAM stereo)"

# rename to a shorter string which isn't truncated on the System Information screen: NB for people who have Guided setup with the real digital cable, this won't be appropriate
# 

setUIText GuidedSetup 63 "Digital Cable/Digital Terrestrial with Set-top Box" "Digital Cable/Terrestrial STB"
setUIText GuidedSetup 63 "DTT lineup (Sky Radio)" "Digital Cable/Terrestrial STB"

# renamed satellite receiver  NB not correct for Freesat(tm) 
# @@

#setUIText GuidedSetup 69 "Satellite Receiver" "Sky Digibox"

# As I use a pacelink cable, I renamed this too, unlikely to be suitable for most people
# 

#setUIText GuidedSetup 88 "Box with Infrared Blaster" "with IR cable"

# Fix the USA spelling for the title of the error page you get in tivo's menus when you select "record this episode" on a programme that has already started:

setUIText PickProgrammes 151 "Program in Progress" "Programme in Progress"

# Grammar fixes

setUIText PickProgrammes 54 "There are %d upcoming episodes" "There are %d upcoming episodes."
setUIText PickProgrammes 55 "There is one upcoming episode" "There is 1 upcoming episode."
setUIText PickProgrammes 56 "There are no upcoming episodes" "There are no upcoming episodes."

# Add more options to Keep At Least: The "month" option is cheating slightly, but anyway it's nice to have to Britishness in there.

setUIText RecordingOptions 25 "Until space needed|0|1 day|1|2 days|2|3 days|3|4 days|4|5 days|5|6 days|6|7 days|7|Until I delete|-1|" "Until space needed|0|Until I delete|-1|1 day|1|2 days|2|3 days|3|4 days|4|5 days|5|6 days|6|A week|7|10 days|10|A fortnight|14|3 weeks|21|A month|30|"

# Rename First Run options:

setUIText RecordingOptions 29 "Repeats & first run|1|First run only|0|" "Old & new episodes|1|New episodes only|0|"

# start padding

setUIText RecordingOptions 31 "On-time|0|1 minute early|60|2 minutes early|120|3 minutes early|180|4 minutes early|240|5 minutes early|300|10 minutes early|600|" "On time|0|1/2 a minute early|30|1 minute early|60|2 minutes early|120|3 minutes early|180|4 minutes early|240|5 minutes early|300|10 minutes early|600|15 minutes early|900|20 minutes early|1200|25 minutes early|1500|30 minutes early|1800|"

# end padding

setUIText RecordingOptions 33 "On-time|0|1 minute longer|60|2 minutes longer|120|5 minutes longer|300|15 minutes longer|900|30 minutes longer|1800|1 hour longer|3600|1 1/2 hours longer|5400|3 hours longer|10800|" "On time|0|1/2 a minute longer|30|1 minute longer|60|2 minutes longer|120|3 minutes longer|180|4 minutes longer|240|5 minutes longer|300|10 minutes longer|600|15 minutes longer|900|20 minutes longer|1200|25 minutes longer|1500|30 minutes longer|1800|35 minutes longer|2100|40 minutes longer|2400|45 minutes longer|2700|50 minutes longer|3000|55 minutes longer|3300|1 hour longer|3600|1 1/4 hours longer|4500|1 1/2 hours longer|5400|1 3/4 hours longer|6300|2 hours longer|7200|3 hours longer|10800|"

set old "If you have call waiting and would like to temporarily disable it while the Recorder calls, so the call is not interrupted, enter the necessary dialling prefix here ('*70,' in most areas).  Press CLEAR for * and ENTER for #.  Press PAUSE to enter a comma (2 sec. pause). To delete a prefix, press BACK.  Press SELECT when done."
set new "If you want to restrict the days and times when TiVo makes daily calls, enter the restriction code here.  Go to http://www.altepg.com/callScheduling for information about restriction codes.  Press CLEAR for *, PAUSE for comma(,) and ENTER for #. To delete a prefix, press BACK.  Press SELECT when done.\n\nExample restriction codes\n,12345# - call only at weekends\n,2* - call every other day"
setUIText GuidedSetup 221 $old $new

setUIText GuidedSetup 220 "Call Waiting" "Call Scheduling"

setUIText GuidedSetup 223 "Set Call Waiting Prefix:" "Set Call Scheduling Rules:"

setUIText GuidedSetup 225 "Use these dialling options" "Use these calling options"
setUIText GuidedSetup 227 "Test Phone Connection Now" "Test Phone/Network Now"
setUIText GuidedSetup 227 "Test Phone/Net Connection Now" "Test Phone/Network Now"
setUIText GuidedSetup 229 "Dialling Options Changed" "Calling Options Changed"
setUIText GuidedSetup 231 "Continue changing dialling options" "Continue changing calling options"
setUIText GuidedSetup 233 "Some dialling options have changed.  You must make a successful test call before the new options can be accepted.  Or, if you wish to restore the previous options, choose 'Restore previous options' below." "Some calling options have changed.  You must make a successful test call before the new options can be accepted.  Or, if you wish to restore the previous options, choose 'Restore previous options' below."
setUIText GuidedSetup 234 "Test Phone Connection" "Test Phone/Network"
setUIText GuidedSetup 234 "Test Phone/Network Connection" "Test Phone/Network"
setUIText GuidedSetup 243 "Phone Dialling Options" "Phone/Network Options"
setUIText GuidedSetup 307 "Phone in use." "Phone/Network in use."
setUIText GuidedSetup 308 "Phone not in use." "Phone/Network not in use."
setUIText GuidedSetup 425 "Recorder & Phone Setup" "Recorder & Call Setup"
setUIText GuidedSetup 529 {WARNING:  You are about to repeat Guided Setup.  This will take about 35 minutes of your time.  The Recorder will make two phone calls during Guided Setup.
			Proceed only if you have moved to a new Postal Code or if you want to change your programme source/video input (for example from Aerial Only to Satellite).} {WARNING:  You are about to repeat Guided Setup.  This will take about 35 minutes of your time.  The Recorder will make two phone/network calls during Guided Setup.
			Proceed only if you have moved to a new Postal Code or if you want to change your programme source/video input (for example from Aerial Only to Satellite).}

setUIText GuidedSetup 530 "A phone call is in progress.  You cannot Repeat Guided Setup until the phone call has completed." "A call is in progress.  You cannot Repeat Guided Setup until the call has completed."
setUIText GuidedSetup 543 {Warning: You are about to delete all recorded programmes, Recorder & Phone and Preferences settings, Parental Controls settings and the password, Season Passes, WishLists, the To Do List, Thumbs ratings and TiVo's Suggestions. This will take about an hour. When done, the Recorder will start Guided Setup.

Press LEFT to go back.} {Warning: You are about to delete all recorded programmes, Recorder & Call and Preferences settings, Parental Controls settings and the password, Season Passes, WishLists, the To Do List, Thumbs ratings and TiVo's Suggestions. This will take about an hour. When done, the Recorder will start Guided Setup.

Press LEFT to go back.}

setUIText CallProgress 50 "Call deferred by scheduling rule." "Failure during preparation."
setUIText CallProgress 62 "Failed. Busy calling DIRECTV." "Deferred by scheduling rule."
setUIText CallProgress 23 "Failed. Couldn't dial." "Network reconfigured OK."
setUIText CallProgress 50 "Failure during preparation." "Downloading..."

putlog "setUIText complete."
putlog "- $successCount texts now correct"
putlog "- $errorCount texts remain uncorrected."

# change history

# 2011/08/20 OR_0002 various text corrections
